==> die-engine_3.07.orig.tar.gz: die-engine-3.07/XFileInfo/dialogxfileinfo.h <==
/* Copyright (c) 2021-2022 hors<horsicq@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef DIALOGXFILEINFO_H
#define DIALOGXFILEINFO_H

#include "xfileinfowidget.h"
#include "xshortcutsdialog.h"

namespace Ui {
class DialogXFileInfo;
}

class DialogXFileInfo : public XShortcutsDialog {
    Q_OBJECT

public:
    explicit DialogXFileInfo(QWidget *pParent = nullptr);
    ~DialogXFileInfo();

    virtual void setGlobal(XShortcuts *pShortcuts, XOptions *pXOptions);
    void setData(QIODevice *pDevice, XBinary::FT fileType, QString sString, bool bAuto = false);

private slots:
    void on_pushButtonClose_clicked();

private:
    Ui::DialogXFileInfo *ui;
};

#endif  // DIALOGXFILEINFO_H

==> die-engine_3.09.orig.tar.gz: die-engine-3.09/XFileInfo/dialogxfileinfo.h <==
/* Copyright (c) 2021-2023 hors<horsicq@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
#ifndef DIALOGXFILEINFO_H
#define DIALOGXFILEINFO_H

#include "xfileinfowidget.h"
#include "xshortcutsdialog.h"

namespace Ui {
class DialogXFileInfo;
}

class DialogXFileInfo : public XShortcutsDialog {
    Q_OBJECT

public:
    explicit DialogXFileInfo(QWidget *pParent = nullptr);
    ~DialogXFileInfo();

    virtual void setGlobal(XShortcuts *pShortcuts, XOptions *pXOptions);
    void setData(QIODevice *pDevice, XBinary::FT fileType, const QString &sString, bool bAuto = false);

private slots:
    void on_pushButtonClose_clicked();

private:
    Ui::DialogXFileInfo *ui;
};

#endif  // DIALOGXFILEINFO_H
